@@ -1,6 +1,6 @@
 import json
-from utils.APIV3 import EtsySession
-from resources import ListingResource
+from etsy_apiv3.utils.APIV3 import EtsySession
+from etsy_apiv3.resources import ListingResource
 
 CLIENT_KEY = "hdvqwd0po24bcbnpb3p8m7c9"
 CLIENT_SECRET = "ja6xhs76se"
